pub enum ExecutableItem {
EnumInstance {
base_enum: NameID,
variant: usize,
},
StructInstance,
Unit(Loc<Unit>),
ExternUnit(UnitName, Loc<UnitHead>),
}Expand description
Items which have associated code that can be executed. This is different from type declarations which are items, but which do not have code on their own
Variants