pub enum PatternKind {
Integer(BigInt),
Bool(bool),
Name {
name: Loc<NameID>,
pre_declared: bool,
},
Tuple(Vec<Loc<Pattern>>),
Array(Vec<Loc<Pattern>>),
Type(Loc<NameID>, Vec<PatternArgument>),
}Variants
Integer(BigInt)
Bool(bool)
Name
Tuple(Vec<Loc<Pattern>>)
Array(Vec<Loc<Pattern>>)
Type(Loc<NameID>, Vec<PatternArgument>)
Instantiation of an entity. While the argument contains information about argument names, for codegen purposes, the arguments must be ordered in the target order. I.e. they should all act as positioanl arguments
Implementations
Sourceimpl PatternKind
impl PatternKind