pub enum TypeSpec {
Declared(Loc<NameID>, Vec<Loc<TypeExpression>>),
Generic(Loc<NameID>),
Tuple(Vec<Loc<TypeSpec>>),
Array {
inner: Box<Loc<TypeSpec>>,
size: Box<Loc<TypeExpression>>,
},
Inverted(Box<Loc<TypeSpec>>),
Wire(Box<Loc<TypeSpec>>),
TraitSelf(Loc<()>),
Wildcard(Loc<()>),
}Expand description
A specification of a type to be used. For example, the types of input/output arguments the type of fields in a struct etc.
Variants
Declared(Loc<NameID>, Vec<Loc<TypeExpression>>)
The type is a declared type (struct, enum, typedef etc.) with n arguments
Generic(Loc<NameID>)
The type is a generic argument visible in the current scope
Tuple(Vec<Loc<TypeSpec>>)
The type is a tuple of other variables
Array
Inverted(Box<Loc<TypeSpec>>)
Wire(Box<Loc<TypeSpec>>)
TraitSelf(Loc<()>)
The type of the self parameter in a trait method spec. Should not
occur in non-traits. The Loc is only used for diag_bails, so an approximate
reference is fine.
Wildcard(Loc<()>)
A wildcard, cannot occur everywhere, but ast lowering enusres that wildcards are valid, i.e. it is safe to emit a Diagnostic::bug if this is encountered where it is invalid
Implementations
Sourceimpl TypeSpec
impl TypeSpec
pub fn unit() -> Self
pub fn type_params(&self) -> Vec<TypeExpression>
pub fn replace_in(self, from: &TypeSpec, to: &TypeSpec) -> Self